@@ -100,6 +100,9 @@ class DebateState:
     running_critiques: List[Dict[str, str]] = field(default_factory=list)  # [{critic, target}, ...] for in-progress
     consensus_reached: bool = False
     consensus_reached_round: int = 0
+    # Round-specific tracking for persistent display
+    round_summaries: Dict[int, List[CritiqueSummary]] = field(default_factory=dict)  # round -> completed critiques
+    round_consensus: Dict[int, float] = field(default_factory=dict)  # round -> consensus after round
 
     # Pope synthesis
     pope_status: str = "pending"
@@ -220,6 +223,9 @@ def handle_event(state: DebateState, event: dict) -> None:
         state.current_round = event['round']
         state.max_rounds = event['maxRounds']
         state.critique_pairs = event['pairs']
+        # Initialize round tracking
+        if state.current_round not in state.round_summaries:
+            state.round_summaries[state.current_round] = []
 
     elif event_type == 'critique_start':
         critic = event['critic']
@@ -251,6 +257,9 @@ def handle_event(state: DebateState, event: dict) -> None:
         existing = [(c.critic, c.target) for c in state.critique_summaries]
         if (new_summary.critic, new_summary.target) not in existing:
             state.critique_summaries.append(new_summary)
+            # Also track by round for persistent display
+            if state.current_round in state.round_summaries:
+                state.round_summaries[state.current_round].append(new_summary)
 
     elif event_type == 'critique_complete':
         # Also handle critique_complete (backup for critique_summary)
@@ -268,6 +277,8 @@ def handle_event(state: DebateState, event: dict) -> None:
 
     elif event_type == 'critique_round_complete':
         state.consensus_score = event['consensusScore']
+        # Store consensus for this round (for persistent display)
+        state.round_consensus[state.current_round] = event['consensusScore']
 
     elif event_type == 'consensus_reached':
         state.consensus_reached = True
@@ -539,11 +550,15 @@ def build_proposals_panel(state: DebateState) -> Panel:
     """Build Stage 1 proposals panel with grid display."""
     elements = []
 
-    # Pope observer with calm watching animation
-    observer = get_pope_observe()
-    pulse = get_pulse()
-    elements.append(Text(f"👑 Pope {format_model_name(state.pope)} observing ", style="grey50") +
-                   Text(f"{observer} {pulse}", style=GOLD))
+    # Pope observer - only animate during Stage 1
+    if state.stage == 1:
+        observer = get_pope_observe()
+        pulse = get_pulse()
+        elements.append(Text(f"👑 Pope {format_model_name(state.pope)} observing ", style="grey50") +
+                       Text(f"{observer} {pulse}", style=GOLD))
+    else:
+        # Stage complete - static text
+        elements.append(Text(f"👑 Pope {format_model_name(state.pope)} observed", style="grey50"))
     elements.append(Text(""))
 
     # Build grid table for bishops
@@ -621,19 +636,21 @@ def build_proposals_panel(state: DebateState) -> Panel:
             label = "LOW"
         elements.append(Text(f"📊 Consensus: ", style="dim") + Text(f"{score_pct}% ({label})", style=f"bold {style}"))
 
-    # Pope assessment result
+    # Pope assessment result - shows consensus level (debate decision is based on complexity, not consensus)
     if state.pope_assessment_done:
         elements.append(Text(""))
         sim_pct = int(state.overall_similarity * 100)
-        if state.should_debate:
+        if sim_pct >= 80:
+            # High consensus - but debate still happens for non-trivial queries
             elements.append(Text(f"⚖️ Pope Assessment: ", style="dim") +
-                          Text(f"{sim_pct}% similarity - debate needed", style=GOLD))
+                          Text(f"{sim_pct}% consensus (high agreement)", style=GREEN))
+        else:
+            # Lower consensus
+            elements.append(Text(f"⚖️ Pope Assessment: ", style="dim") +
+                          Text(f"{sim_pct}% consensus", style=GOLD))
             if state.disagreement_pairs:
                 pairs_str = ", ".join([f"{p['bishop1']} vs {p['bishop2']}" for p in state.disagreement_pairs[:2]])
-                elements.append(Text(f"   Disagreements: {pairs_str}", style="dim"))
-        else:
-            elements.append(Text(f"⚖️ Pope Assessment: ", style="dim") +
-                          Text(f"{sim_pct}% similarity - skipping debate", style=GREEN))
+                elements.append(Text(f"   Areas of disagreement: {pairs_str}", style="dim"))
 
     # Build title with timing
     stage_time = get_stage_time(state, 1)
@@ -648,7 +665,7 @@ def build_proposals_panel(state: DebateState) -> Panel:
 
 
 def build_critiques_panel(state: DebateState) -> Panel:
-    """Build Stage 2 critiques panel with summary grid."""
+    """Build Stage 2 critiques panel with persistent round-by-round display."""
     elements = []
 
     # Build title with timing
@@ -665,73 +682,106 @@ def build_critiques_panel(state: DebateState) -> Panel:
             padding=(0, 2)
         )
 
-    # Round info with progress indicator and explanation
-    if state.current_round > 0:
-        round_text = Text()
-        if state.stage >= 3:
-            # Stage 2 complete - static display
-            round_text.append(f"🛡️ Completed {state.current_round} round{'s' if state.current_round > 1 else ''}", style=f"bold {GOLD}")
-        else:
-            # Still in progress
-            round_text.append(f"🛡️ Round {state.current_round} of {state.max_rounds}", style=f"bold {GOLD}")
-        round_text.append(f" • ", style="dim")
-        round_text.append(f"{state.critique_pairs} disagreeing pairs", style=GOLD)
-        elements.append(round_text)
-        # Explain what determines rounds (only during active phase)
-        if state.current_round == 1 and state.stage < 3:
-            elements.append(Text("   Rounds continue until consensus (>85%) or max rounds reached", style="dim italic"))
-    else:
-        spinner = get_spinner()
-        elements.append(Text(f"🛡️ {spinner} Adversarial critique phase starting...", style=GOLD))
-
     # Pope presiding - show animation only during active critiques, static when done
     if state.stage >= 3 or state.consensus_reached:
-        # Stage 2 complete - static display
-        elements.append(Text(f"👑 Pope {format_model_name(state.pope)} presided", style="grey50"))
+        elements.append(Text(f"👑 Pope {format_model_name(state.pope)} presided over debate", style="grey50"))
     else:
-        # Active - show animation
         preside = get_pope_preside()
         pulse = get_pulse()
         elements.append(Text(f"👑 Pope {format_model_name(state.pope)} presiding ", style="grey50") +
                        Text(f"{preside} {pulse}", style=GOLD))
     elements.append(Text(""))
 
-    # Show running critiques first (with spinner only - no redundant animations)
-    if state.running_critiques:
-        for crit in state.running_critiques:
-            spinner = get_spinner()
-            row_text = Text()
-            row_text.append(f"  {spinner} ", style=CYAN)
-            row_text.append(f"{format_model_name(crit['critic'])}", style=CYAN)
-            row_text.append(" → ", style="dim")
-            row_text.append(f"{format_model_name(crit['target'])} ", style=CYAN)
-            row_text.append("critiquing", style="dim italic")
-            elements.append(row_text)
+    # Display completed rounds persistently
+    completed_rounds = sorted([r for r in state.round_summaries.keys() if r < state.current_round or state.stage >= 3])
+    for round_num in completed_rounds:
+        round_critiques = state.round_summaries.get(round_num, [])
+        round_cons = state.round_consensus.get(round_num)
 
-    # Show completed critiques (with checkmarks and summaries)
-    if state.critique_summaries:
-        for crit in state.critique_summaries:
+        # Round header
+        round_header = Text()
+        round_header.append(f"  Round {round_num}", style=f"bold {GOLD}")
+        if round_cons is not None:
+            cons_pct = int(round_cons * 100)
+            round_header.append(f" • ", style="dim")
+            round_header.append(f"{cons_pct}% consensus", style="dim")
+        round_header.append(f" ✓", style=GREEN)
+        elements.append(round_header)
+
+        # Critiques for this round
+        for crit in round_critiques:
             severity_color = {'critical': 'red', 'moderate': GOLD, 'minor': GREEN}.get(crit.severity, GREEN)
             row_text = Text()
-            row_text.append(f"  ✓ ", style=GREEN)
+            row_text.append(f"    ✓ ", style=GREEN)
             row_text.append(f"{format_model_name(crit.critic)}", style=CYAN)
             row_text.append(" → ", style="dim")
             row_text.append(f"{format_model_name(crit.target)} ", style=CYAN)
             row_text.append(f"[{crit.severity.upper()}] ", style=f"bold {severity_color}")
-            row_text.append(crit.summary[:60], style="dim")
+            row_text.append(crit.summary[:50], style="dim")
             elements.append(row_text)
-
-    # Consensus reached?
-    if state.consensus_reached:
         elements.append(Text(""))
+
+    # Current round (if in progress)
+    if state.current_round > 0 and state.stage < 3 and not state.consensus_reached:
+        # Check if this round has any completed critiques yet
+        current_round_done = state.current_round in completed_rounds
+        if not current_round_done:
+            round_header = Text()
+            spinner = get_spinner()
+            round_header.append(f"  {spinner} Round {state.current_round}", style=f"bold {GOLD}")
+            round_header.append(f" of {state.max_rounds}", style="dim")
+            round_header.append(f" • ", style="dim")
+            round_header.append(f"{state.critique_pairs} pairs critiquing", style=GOLD)
+            elements.append(round_header)
+
+            # Show running critiques for current round
+            for crit in state.running_critiques:
+                spinner = get_spinner()
+                row_text = Text()
+                row_text.append(f"    {spinner} ", style=CYAN)
+                row_text.append(f"{format_model_name(crit['critic'])}", style=CYAN)
+                row_text.append(" → ", style="dim")
+                row_text.append(f"{format_model_name(crit['target'])} ", style=CYAN)
+                row_text.append("critiquing...", style="dim italic")
+                elements.append(row_text)
+
+            # Show completed critiques in current round (not yet moved to round_summaries)
+            current_round_critiques = state.round_summaries.get(state.current_round, [])
+            for crit in current_round_critiques:
+                severity_color = {'critical': 'red', 'moderate': GOLD, 'minor': GREEN}.get(crit.severity, GREEN)
+                row_text = Text()
+                row_text.append(f"    ✓ ", style=GREEN)
+                row_text.append(f"{format_model_name(crit.critic)}", style=CYAN)
+                row_text.append(" → ", style="dim")
+                row_text.append(f"{format_model_name(crit.target)} ", style=CYAN)
+                row_text.append(f"[{crit.severity.upper()}] ", style=f"bold {severity_color}")
+                row_text.append(crit.summary[:50], style="dim")
+                elements.append(row_text)
+
+    # Starting message if no rounds yet
+    if state.current_round == 0:
+        spinner = get_spinner()
+        elements.append(Text(f"  {spinner} Adversarial critique phase starting...", style=GOLD))
+
+    # Consensus reached message
+    if state.consensus_reached:
         score_pct = int(state.consensus_score * 100) if state.consensus_score else 0
         consensus_text = Text()
         consensus_text.append("✓ ", style=GREEN)
         consensus_text.append(f"Consensus reached!", style=f"bold {GREEN}")
-        consensus_text.append(f" ({score_pct}% agreement after round {state.consensus_reached_round})", style="dim")
+        consensus_text.append(f" ({score_pct}% after round {state.consensus_reached_round})", style="dim")
         elements.append(consensus_text)
         if state.consensus_reached_round < state.max_rounds:
-            elements.append(Text(f"   Remaining {state.max_rounds - state.consensus_reached_round} rounds skipped", style="dim italic"))
+            elements.append(Text(f"   Skipped {state.max_rounds - state.consensus_reached_round} remaining round(s)", style="dim italic"))
+
+    # Final summary when stage 2 complete
+    if state.stage >= 3 and not state.consensus_reached:
+        final_cons = int(state.consensus_score * 100) if state.consensus_score else 0
+        summary_text = Text()
+        summary_text.append(f"✓ ", style=GREEN)
+        summary_text.append(f"Debate complete", style=f"bold {GREEN}")
+        summary_text.append(f" • {state.current_round} round(s) • {final_cons}% final consensus", style="dim")
+        elements.append(summary_text)
 
     # Show completion status in title when stage 2 is done
     if state.stage >= 3:
@@ -1085,7 +1135,10 @@ def build_status_bar(state: DebateState) -> Text:
 
 
 def build_display(state: DebateState) -> Group:
-    """Build full display from current state."""
+    """Build full display from current state.
+
+    Shows all stages - terminal will scroll naturally if content exceeds height.
+    """
     panels = []
 
     # Error takes precedence
@@ -1426,18 +1479,36 @@ async def run_cloud_debate(
     work_dir = working_directory or os.getcwd()
     proj_path = project_path or work_dir
 
-    # Gather auto-context (zero-latency, runs in parallel with user seeing spinner)
-    auto_files, auto_file_paths = await gather_auto_context(
-        query=query,
-        root_path=proj_path,
-    )
-    if auto_file_paths:
-        display_auto_context_summary(auto_files, auto_file_paths)
-
-    with Live(console=console, refresh_per_second=12, transient=False) as live:
+    # Start Live display IMMEDIATELY so user sees Stage 0 animation right away
+    # vertical_overflow="visible" allows content to scroll naturally when it exceeds terminal height
+    with Live(console=console, refresh_per_second=12, transient=False, vertical_overflow="visible") as live:
         # Show initial Stage 0 display immediately (timer starts counting)
         live.update(build_display(state))
 
+        # Gather auto-context while showing Stage 0 animation
+        # Use a task so we can update display during context gathering
+        auto_context_task = asyncio.create_task(gather_auto_context(
+            query=query,
+            root_path=proj_path,
+        ))
+
+        # Update display while waiting for auto-context
+        while not auto_context_task.done():
+            try:
+                await asyncio.wait_for(asyncio.shield(auto_context_task), timeout=0.1)
+            except asyncio.TimeoutError:
+                advance_animation()
+                live.update(build_display(state))
+
+        auto_files, auto_file_paths = auto_context_task.result()
+
+        # Show auto-context summary (briefly pause live to print)
+        if auto_file_paths:
+            live.stop()
+            display_auto_context_summary(auto_files, auto_file_paths)
+            live.start()
+            live.update(build_display(state))
+
         # Process initial debate stream with auto-context
         event_stream = stream_sse(
             url=api_url,
